mailr9130 - /branches/frame_order/maths_fns/frame_order_models.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 23, 2009 - 11:31:
Author: bugman
Date: Tue Jun 23 11:31:59 2009
New Revision: 9130

URL: http://svn.gna.org/viewcvs/relax?rev=9130&view=rev
Log:
Added the cone axis storage structure.


Modified:
    branches/frame_order/maths_fns/frame_order_models.py

Modified: branches/frame_order/maths_fns/frame_order_models.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order/maths_fns/frame_order_models.py?rev=9130&r1=9129&r2=9130&view=diff
==============================================================================
--- branches/frame_order/maths_fns/frame_order_models.py (original)
+++ branches/frame_order/maths_fns/frame_order_models.py Tue Jun 23 11:31:59 
2009
@@ -114,7 +114,8 @@
         self.red_errors = red_errors
         self.red_tensors_bc = zeros(self.num_tensors*5, float64)
 
-        # The molecular frame z-axis.
+        # The cone axis storage and molecular frame z-axis.
+        self.cone_axis = zeros(3, float64)
         self.z_axis = array([0, 0, 1], float64)
 
         # The rotation to the Frame Order eigenframe.
@@ -142,7 +143,8 @@
         # The errors.
         self.errors = ones((9, 9), float64)
 
-        # The molecular frame z-axis.
+        # The cone axis storage and molecular frame z-axis.
+        self.cone_axis = zeros(3, float64)
         self.z_axis = array([0, 0, 1], float64)
 
         # The rotation.
@@ -173,7 +175,7 @@
         theta, phi, theta_cone = params
 
         # Generate the 2nd degree Frame Order super matrix.
-        self.frame_order_2nd = 
compile_2nd_matrix_iso_cone(self.frame_order_2nd, self.rot, self.z_axis, 
theta, phi, theta_cone)
+        self.frame_order_2nd = 
compile_2nd_matrix_iso_cone(self.frame_order_2nd, self.rot, self.z_axis, 
self.cone_axis, theta, phi, theta_cone)
 
         # Back calculate the reduced tensors.
         for i in range(self.num_tensors):
@@ -202,7 +204,7 @@
         theta, phi, theta_cone = params
 
         # Generate the 2nd degree Frame Order super matrix.
-        self.frame_order_2nd = 
compile_2nd_matrix_iso_cone(self.frame_order_2nd, self.rot, self.z_axis, 
theta, phi, theta_cone)
+        self.frame_order_2nd = 
compile_2nd_matrix_iso_cone(self.frame_order_2nd, self.rot, self.z_axis, 
self.cone_axis, theta, phi, theta_cone)
 
         # Make the Frame Order matrix contiguous.
         self.frame_order_2nd = self.frame_order_2nd.copy()




Related Messages


Powered by MHonArc, Updated Tue Jun 23 11:40:02 2009